==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/migrate/kotlin/inputs/WebApplicationConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.migrate.kotlin.inputs

import com.pulumi.azurenative.migrate.inputs.WebApplicationConfigurationArgs.builder
import com.pulumi.azurenative.migrate.kotlin.enums.ConfigurationType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Class for web application configurations.
 * @property filePath Gets or sets the configuration file path.
 * @property identifier Gets or sets the identifier for the configuration.
 * @property isDeploymentTimeEditable Gets or sets a value indicating whether the configuration is edited or not by the user.
 * @property localFilePath Gets or sets the configuration local file path.
 * @property name Gets or sets the configuration name.
 * @property secretStoreDetails
 * @property section Gets or sets the configuration section in the file.
 * @property targetFilePath Gets or sets the configuration target file path.
 * @property type Gets or sets the configuration type.
 * @property value Gets or sets the configuration value.
 */
public data class WebApplicationConfigurationArgs(
    public val filePath: Output<String>? = null,
    public val identifier: Output<String>? = null,
    public val isDeploymentTimeEditable: Output<Boolean>? = null,
    public val localFilePath: Output<String>? = null,
    public val name: Output<String>? = null,
    public val secretStoreDetails: Output<SecretStoreDetailsArgs>? = null,
    public val section: Output<String>? = null,
    public val targetFilePath: Output<String>? = null,
    public val type: Output<Either<String, ConfigurationType>>? = null,
    public val `value`: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.migrate.inputs.WebApplicationConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.migrate.inputs.WebApplicationConfigurationArgs =
        com.pulumi.azurenative.migrate.inputs.WebApplicationConfigurationArgs.builder()
            .filePath(filePath?.applyValue({ args0 -> args0 }))
            .identifier(identifier?.applyValue({ args0 -> args0 }))
            .isDeploymentTimeEditable(isDeploymentTimeEditable?.applyValue({ args0 -> args0 }))
            .localFilePath(localFilePath?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .secretStoreDetails(
                secretStoreDetails?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .section(section?.applyValue({ args0 -> args0 }))
            .targetFilePath(targetFilePath?.applyValue({ args0 -> args0 }))
            .type(
                type?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .`value`(`value`?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WebApplicationConfigurationArgs].
 */
@PulumiTagMarker
public class WebApplicationConfigurationArgsBuilder internal constructor() {
    private var filePath: Output<String>? = null

    private var identifier: Output<String>? = null

    private var isDeploymentTimeEditable: Output<Boolean>? = null

    private var localFilePath: Output<String>? = null

    private var name: Output<String>? = null

    private var secretStoreDetails: Output<SecretStoreDetailsArgs>? = null

    private var section: Output<String>? = null

    private var targetFilePath: Output<String>? = null

    private var type: Output<Either<String, ConfigurationType>>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value Gets or sets the configuration file path.
     */
    @JvmName("qdaobdsgpprlmwof")
    public suspend fun filePath(`value`: Output<String>) {
        this.filePath = value
    }

    /**
     * @param value Gets or sets the identifier for the configuration.
     */
    @JvmName("kjliwytmrgjghhyu")
    public suspend fun identifier(`value`: Output<String>) {
        this.identifier = value
    }

    /**
     * @param value Gets or sets a value indicating whether the configuration is edited or not by the user.
     */
    @JvmName("haxoifmrqxbikiyj")
    public suspend fun isDeploymentTimeEditable(`value`: Output<Boolean>) {
        this.isDeploymentTimeEditable = value
    }

    /**
     * @param value Gets or sets the configuration local file path.
     */
    @JvmName("rwxwcigxyknxfubf")
    public suspend fun localFilePath(`value`: Output<String>) {
        this.localFilePath = value
    }

    /**
     * @param value Gets or sets the configuration name.
     */
    @JvmName("hvjcfvygxenfajnc")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value
     */
    @JvmName("pyablcklljgwxdxq")
    public suspend fun secretStoreDetails(`value`: Output<SecretStoreDetailsArgs>) {
        this.secretStoreDetails = value
    }

    /**
     * @param value Gets or sets the configuration section in the file.
     */
    @JvmName("omsyjocbgsvlphhi")
    public suspend fun section(`value`: Output<String>) {
        this.section = value
    }

    /**
     * @param value Gets or sets the configuration target file path.
     */
    @JvmName("adkrmwsxvicxckvm")
    public suspend fun targetFilePath(`value`: Output<String>) {
        this.targetFilePath = value
    }

    /**
     * @param value Gets or sets the configuration type.
     */
    @JvmName("dxyamexaicqudhpm")
    public suspend fun type(`value`: Output<Either<String, ConfigurationType>>) {
        this.type = value
    }

    /**
     * @param value Gets or sets the configuration value.
     */
    @JvmName("uqjyvcxtpovpngxi")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value Gets or sets the configuration file path.
     */
    @JvmName("dtjodlyfwuvmasct")
    public suspend fun filePath(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.filePath = mapped
    }

    /**
     * @param value Gets or sets the identifier for the configuration.
     */
    @JvmName("prmjevslawvxsjrj")
    public suspend fun identifier(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.identifier = mapped
    }

    /**
     * @param value Gets or sets a value indicating whether the configuration is edited or not by the user.
     */
    @JvmName("rkncvdbnfwnagrbu")
    public suspend fun isDeploymentTimeEditable(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isDeploymentTimeEditable = mapped
    }

    /**
     * @param value Gets or sets the configuration local file path.
     */
    @JvmName("hlftlcuvdtokbybw")
    public suspend fun localFilePath(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.localFilePath = mapped
    }

    /**
     * @param value Gets or sets the configuration name.
     */
    @JvmName("xucgmthgtpipdaqp")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value
     */
    @JvmName("rfbrkpnuigkjyewp")
    public suspend fun secretStoreDetails(`value`: SecretStoreDetailsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secretStoreDetails = mapped
    }

    /**
     * @param argument
     */
    @JvmName("yioirgbokdnvemnd")
    public suspend
    fun secretStoreDetails(argument: suspend SecretStoreDetailsArgsBuilder.() -> Unit) {
        val toBeMapped = SecretStoreDetailsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.secretStoreDetails = mapped
    }

    /**
     * @param value Gets or sets the configuration section in the file.
     */
    @JvmName("gejjvaokmmjdcesn")
    public suspend fun section(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.section = mapped
    }

    /**
     * @param value Gets or sets the configuration target file path.
     */
    @JvmName("vyiidsihhttgmvjt")
    public suspend fun targetFilePath(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.targetFilePath = mapped
    }

    /**
     * @param value Gets or sets the configuration type.
     */
    @JvmName("inqbuynfoyuyarer")
    public suspend fun type(`value`: Either<String, ConfigurationType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Gets or sets the configuration type.
     */
    @JvmName("xevstycshqnnxlrs")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ConfigurationType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Gets or sets the configuration type.
     */
    @JvmName("hdqvwoxpudkmpxmq")
    public fun type(`value`: ConfigurationType) {
        val toBeMapped = Either.ofRight<String, ConfigurationType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Gets or sets the configuration value.
     */
    @JvmName("gwofsbwabfbugjyg")
    public suspend fun `value`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): WebApplicationConfigurationArgs = WebApplicationConfigurationArgs(
        filePath = filePath,
        identifier = identifier,
        isDeploymentTimeEditable = isDeploymentTimeEditable,
        localFilePath = localFilePath,
        name = name,
        secretStoreDetails = secretStoreDetails,
        section = section,
        targetFilePath = targetFilePath,
        type = type,
        `value` = `value`,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/migrate/kotlin/inputs/WebApplicationConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.migrate.kotlin.inputs

import com.pulumi.azurenative.migrate.inputs.WebApplicationConfigurationArgs.builder
import com.pulumi.azurenative.migrate.kotlin.enums.ConfigurationType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Class for web application configurations.
 * @property filePath Gets or sets the configuration file path.
 * @property identifier Gets or sets the identifier for the configuration.
 * @property isDeploymentTimeEditable Gets or sets a value indicating whether the configuration is edited or not by the user.
 * @property localFilePath Gets or sets the configuration local file path.
 * @property name Gets or sets the configuration name.
 * @property secretStoreDetails
 * @property section Gets or sets the configuration section in the file.
 * @property targetFilePath Gets or sets the configuration target file path.
 * @property type Gets or sets the configuration type.
 * @property value Gets or sets the configuration value.
 */
public data class WebApplicationConfigurationArgs(
    public val filePath: Output<String>? = null,
    public val identifier: Output<String>? = null,
    public val isDeploymentTimeEditable: Output<Boolean>? = null,
    public val localFilePath: Output<String>? = null,
    public val name: Output<String>? = null,
    public val secretStoreDetails: Output<SecretStoreDetailsArgs>? = null,
    public val section: Output<String>? = null,
    public val targetFilePath: Output<String>? = null,
    public val type: Output<Either<String, ConfigurationType>>? = null,
    public val `value`: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.migrate.inputs.WebApplicationConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.migrate.inputs.WebApplicationConfigurationArgs =
        com.pulumi.azurenative.migrate.inputs.WebApplicationConfigurationArgs.builder()
            .filePath(filePath?.applyValue({ args0 -> args0 }))
            .identifier(identifier?.applyValue({ args0 -> args0 }))
            .isDeploymentTimeEditable(isDeploymentTimeEditable?.applyValue({ args0 -> args0 }))
            .localFilePath(localFilePath?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .secretStoreDetails(
                secretStoreDetails?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .section(section?.applyValue({ args0 -> args0 }))
            .targetFilePath(targetFilePath?.applyValue({ args0 -> args0 }))
            .type(
                type?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .`value`(`value`?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WebApplicationConfigurationArgs].
 */
@PulumiTagMarker
public class WebApplicationConfigurationArgsBuilder internal constructor() {
    private var filePath: Output<String>? = null

    private var identifier: Output<String>? = null

    private var isDeploymentTimeEditable: Output<Boolean>? = null

    private var localFilePath: Output<String>? = null

    private var name: Output<String>? = null

    private var secretStoreDetails: Output<SecretStoreDetailsArgs>? = null

    private var section: Output<String>? = null

    private var targetFilePath: Output<String>? = null

    private var type: Output<Either<String, ConfigurationType>>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value Gets or sets the configuration file path.
     */
    @JvmName("jklgdivdpcykdasp")
    public suspend fun filePath(`value`: Output<String>) {
        this.filePath = value
    }

    /**
     * @param value Gets or sets the identifier for the configuration.
     */
    @JvmName("bjanonvrpfigxqif")
    public suspend fun identifier(`value`: Output<String>) {
        this.identifier = value
    }

    /**
     * @param value Gets or sets a value indicating whether the configuration is edited or not by the user.
     */
    @JvmName("mehixpckysxgxoqy")
    public suspend fun isDeploymentTimeEditable(`value`: Output<Boolean>) {
        this.isDeploymentTimeEditable = value
    }

    /**
     * @param value Gets or sets the configuration local file path.
     */
    @JvmName("bpyemrrwijxoanoy")
    public suspend fun localFilePath(`value`: Output<String>) {
        this.localFilePath = value
    }

    /**
     * @param value Gets or sets the configuration name.
     */
    @JvmName("vylfpyklhquiniee")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value
     */
    @JvmName("xbiknwmxbvrfdgci")
    public suspend fun secretStoreDetails(`value`: Output<SecretStoreDetailsArgs>) {
        this.secretStoreDetails = value
    }

    /**
     * @param value Gets or sets the configuration section in the file.
     */
    @JvmName("mddxyrxxsidvoqhs")
    public suspend fun section(`value`: Output<String>) {
        this.section = value
    }

    /**
     * @param value Gets or sets the configuration target file path.
     */
    @JvmName("genfdiifeuwakxxk")
    public suspend fun targetFilePath(`value`: Output<String>) {
        this.targetFilePath = value
    }

    /**
     * @param value Gets or sets the configuration type.
     */
    @JvmName("kkoshuoagttjqmhb")
    public suspend fun type(`value`: Output<Either<String, ConfigurationType>>) {
        this.type = value
    }

    /**
     * @param value Gets or sets the configuration value.
     */
    @JvmName("rywewrhahobpdmwj")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value Gets or sets the configuration file path.
     */
    @JvmName("tlykaiegkddpmbps")
    public suspend fun filePath(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.filePath = mapped
    }

    /**
     * @param value Gets or sets the identifier for the configuration.
     */
    @JvmName("ibdygxjruiblawuv")
    public suspend fun identifier(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.identifier = mapped
    }

    /**
     * @param value Gets or sets a value indicating whether the configuration is edited or not by the user.
     */
    @JvmName("ylquxvhqybmsfiqh")
    public suspend fun isDeploymentTimeEditable(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.isDeploymentTimeEditable = mapped
    }

    /**
     * @param value Gets or sets the configuration local file path.
     */
    @JvmName("cjogmvfgsjdgiuna")
    public suspend fun localFilePath(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.localFilePath = mapped
    }

    /**
     * @param value Gets or sets the configuration name.
     */
    @JvmName("evwbgdvybbnvhwbq")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value
     */
    @JvmName("qfmcvnuriieffntw")
    public suspend fun secretStoreDetails(`value`: SecretStoreDetailsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secretStoreDetails = mapped
    }

    /**
     * @param argument
     */
    @JvmName("couiguqurykfxxsp")
    public suspend
    fun secretStoreDetails(argument: suspend SecretStoreDetailsArgsBuilder.() -> Unit) {
        val toBeMapped = SecretStoreDetailsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.secretStoreDetails = mapped
    }

    /**
     * @param value Gets or sets the configuration section in the file.
     */
    @JvmName("cnyevaevoqdnhsri")
    public suspend fun section(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.section = mapped
    }

    /**
     * @param value Gets or sets the configuration target file path.
     */
    @JvmName("ggbplywyydaogiuc")
    public suspend fun targetFilePath(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.targetFilePath = mapped
    }

    /**
     * @param value Gets or sets the configuration type.
     */
    @JvmName("phyyayjgkjhqmhpu")
    public suspend fun type(`value`: Either<String, ConfigurationType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Gets or sets the configuration type.
     */
    @JvmName("ktdorptxhyxvhqhq")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ConfigurationType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Gets or sets the configuration type.
     */
    @JvmName("kjawwpxdbfppybpj")
    public fun type(`value`: ConfigurationType) {
        val toBeMapped = Either.ofRight<String, ConfigurationType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Gets or sets the configuration value.
     */
    @JvmName("vqfcbwvbshwdpaiq")
    public suspend fun `value`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): WebApplicationConfigurationArgs = WebApplicationConfigurationArgs(
        filePath = filePath,
        identifier = identifier,
        isDeploymentTimeEditable = isDeploymentTimeEditable,
        localFilePath = localFilePath,
        name = name,
        secretStoreDetails = secretStoreDetails,
        section = section,
        targetFilePath = targetFilePath,
        type = type,
        `value` = `value`,
    )
}
